==> snips-sam-0.0.7.tgz: package/src/commands/deploy.ts <==
import * as yargs from 'yargs';
import { cli } from '../cli';
import { SSHService } from '../session/ssh';
import path = require('path');
import chalk from 'chalk';
import { Snipsfile } from '../models/snipsfile';

export const command = 'deploy';
export const desc = 'Deploy an assistant';

exports.builder = {
    snipsfile_path: {
        demandOption: false,
        describe: 'Location of the Snipsfile',
        type: 'string',
        alias: 'sp',
    },
    assistant_path: {
        demandOption: false,
        describe: `Location of the assistant, zip or folder. It's name should be also reflected in the Snipsfile`,
        type: 'string',
        alias: 'ap',
    },
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
};

export const handler = async (argv: yargs.Argv) => {
    let snipsfilePath = JSON.parse(JSON.stringify(argv)).snipsfile_path;
    const assistantPath: string = JSON.parse(JSON.stringify(argv)).assistant_path;
    const verbose = JSON.parse(JSON.stringify(argv)).verbose;

    if (snipsfilePath === undefined) {
        snipsfilePath = path.join(process.cwd(), 'Snipsfile');
    }

    const snipsfile = await Snipsfile.parse(snipsfilePath)
    .catch((e) => {
        cli.stream.done(false);
        cli.stream.errorPlain(`Error: Could not locate Snipsfile`);
        process.exit();
    });
    if (snipsfile === undefined) {
        cli.stream.done(false);
        cli.stream.errorPlain(`Error: Could not locate Snipsfile`);
        return process.exit();
    }

    const ssh = new SSHService();
    await ssh.connect()
    .catch((e) => {
        cli.stream.error(e);
        process.exit();
    });

    if (assistantPath !== undefined) {
        cli.stream.loading(`Deploying assistant to ${ssh.credentials.hostname}...`);
        const assistantName = path.basename(assistantPath);
        if (assistantName.includes('zip')) {
            await ssh.putFile(assistantPath, assistantName)
            .catch((e) => {
                cli.stream.done(false);
                cli.stream.errorPlain(`Error: Could not send assistant file`);
                process.exit();
            });
        } else {
            await ssh.putDirectory(assistantPath, 'assistant.zip')
            .catch((e) => {
                cli.stream.done(false);
                cli.stream.errorPlain(`Error: Could not send assistant file`);
                process.exit();
            });
        }
        cli.stream.done();
    }

    cli.stream.loading(`Copying Snipsfile to device...`);
    await ssh.putFile(snipsfilePath, 'Snipsfile')
    .catch((e) => {
        cli.stream.done(false);
        cli.stream.errorPlain(`Error deploying assistant: ${e.message}`);
        ssh.disconnect();
        process.exit();
    });
    cli.stream.done();

    let consoleUsername = '';
    let consolePassword = '';
    if (snipsfile.assistantId !== undefined) {
        const responses = await cli.prompt.promptQuestions(
            [
                {
                    name: 'username',
                    type: 'username',
                    message: 'Enter username for the Snips Console:',
                    validate: (value) => {
                        if (value.length) {
                            return true;
                        }
                        return 'Username cannot be blank';
                    },
                },
                {
                    name: 'password',
                    type: 'password',
                    message: 'Enter password for Snips Console:',
                    validate: (value) => {
                        return true;
                    },
                },
            ],
        );
        consoleUsername = responses['username'];
        consolePassword = responses['password'];
    }

    cli.stream.loading('Installing dependencies. This may take a few minutes...');
    await ssh.runSnipsmanagerInstall(consoleUsername, consolePassword, (output) => {
        if (verbose) {
            cli.stream.done();
            cli.stream.println(output);
        }
    });
    cli.stream.done();

    // cli.stream.loading('Adding snipsmanager as a systemd service...');
    // await timeout(1000);
    // cli.stream.done();

    cli.stream.loading('Starting assistant...');

    await ssh.runSnipsManager((output) => {
        cli.stream.done(true);
        if (verbose) {
            cli.stream.println(output);
        }
    });

    const assistant = await ssh.getInstalledAssistant();

    cli.stream.done();
    cli.stream.println();

    if (assistant !== undefined) {
        cli.stream.success(`Snips assistant is now running. Say ${chalk.blue(assistant.hotword)} to start!`);
    } else {
        cli.stream.success(`Snips assistant is now running`);
    }

    ssh.disconnect();
    process.exit();
};

==> snips-sam-0.0.8.tgz: package/src/commands/deploy.ts <==
import * as yargs from 'yargs';
import { cli } from '../cli';
import { SSHService } from '../session/ssh';
import path = require('path');
import chalk from 'chalk';
import { Snipsfile } from '../models/snipsfile';

export const command = 'deploy';
export const desc = 'Deploy the Snipsfile';

exports.builder = {
    snipsfile_path: {
        demandOption: false,
        describe: 'Location of the Snipsfile',
        type: 'string',
        alias: 'sp',
    },
    assistant_path: {
        demandOption: false,
        describe: `Location of the assistant, zip or folder. It's name should be also reflected in the Snipsfile`,
        type: 'string',
        alias: 'ap',
    },
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
};

export const handler = async (argv: yargs.Argv) => {
    let snipsfilePath = JSON.parse(JSON.stringify(argv)).snipsfile_path;
    const assistantPath: string = JSON.parse(JSON.stringify(argv)).assistant_path;
    const verbose = JSON.parse(JSON.stringify(argv)).verbose;

    if (snipsfilePath === undefined) {
        snipsfilePath = path.join(process.cwd(), 'Snipsfile');
    }

    const snipsfile = await Snipsfile.parse(snipsfilePath)
    .catch((e) => {
        cli.stream.done(false);
        cli.stream.errorPlain(`Error: Could not locate Snipsfile`);
        process.exit();
    });
    if (snipsfile === undefined) {
        cli.stream.done(false);
        cli.stream.errorPlain(`Error: Could not locate Snipsfile`);
        return process.exit();
    }

    const ssh = new SSHService();
    await ssh.connect()
    .catch((e) => {
        cli.stream.error(e);
        process.exit();
    });

    if (assistantPath !== undefined) {
        cli.stream.loading(`Deploying assistant to ${ssh.credentials.hostname}...`);
        await ssh.installAssistant(assistantPath)
        .catch((e) => {
            cli.stream.error('Unable to install the assistant:' + e.message);
            ssh.disconnect();
            process.exit();
        });
        cli.stream.success();
    }

    cli.stream.loading(`Copying Snipsfile to device...`);
    await ssh.putFile(snipsfilePath, 'Snipsfile')
    .catch((e) => {
        cli.stream.done(false);
        cli.stream.errorPlain(`Error deploying assistant: ${e.message}`);
        ssh.disconnect();
        process.exit();
    });
    cli.stream.done();

    let consoleUsername = '';
    let consolePassword = '';
    if (snipsfile.assistantId !== undefined) {
        const responses = await cli.prompt.promptQuestions(
            [
                {
                    name: 'username',
                    type: 'username',
                    message: 'Enter username for the Snips Console:',
                    validate: (value) => {
                        if (value.length) {
                            return true;
                        }
                        return 'Username cannot be blank';
                    },
                },
                {
                    name: 'password',
                    type: 'password',
                    message: 'Enter password for Snips Console:',
                    validate: (value) => {
                        return true;
                    },
                },
            ],
        );
        consoleUsername = responses['username'];
        consolePassword = responses['password'];
    }

    cli.stream.loading('Installing dependencies. This may take a few minutes...');
    await ssh.runSnipsmanagerInstall(consoleUsername, consolePassword, (output) => {
        if (verbose) {
            cli.stream.done();
            cli.stream.println(output);
        }
    });
    cli.stream.done();

    cli.stream.loading('Starting assistant...');

    await ssh.runSnipsManager((output) => {
        cli.stream.done(true);
        if (verbose) {
            cli.stream.println(output);
        }
    });

    const assistant = await ssh.getInstalledAssistant();

    cli.stream.done();
    cli.stream.println();

    if (assistant !== undefined) {
        cli.stream.success(`Snips assistant is now running. Say ${chalk.blue(assistant.hotword)} to start!`);
    } else {
        cli.stream.success(`Snips assistant is now running`);
    }

    ssh.disconnect();
    process.exit();
};
